mix lint (neo_faker v0.6.1)
View SourceRuns mix format, mix test, mix dialyzer, and mix credo sequentially to check code quality.
This task is REQUIRED for contributors to run before submitting a Pull Request (PR). Ensure all checks pass to maintain code consistency and correctness.