Functions for generating person-related information specific to Indonesia.
This module provides utilities to generate random personal details specific to Indonesia, such as Nomor Induk Kependudukan (NIK).
Summary
Functions
@spec nik() :: String.t()
Generates a random NIK.
Returns a random NIK (Nomor Induk Kependudukan).
Examples
iex> NeoFaker.IdId.Person.nik()
"7645504903500640"
@spec npwp() :: String.t()
Generates a random NPWP.
Returns a random NPWP (Nomor Pokok Wajib Pajak), the tax identification number defined by UU No. 7 Tahun 2021 tentang Harmonisasi Peraturan Perpajakan (HPP); it uses the same format as NIK.
Examples
iex> NeoFaker.IdId.Person.npwp()
"7645504903500640"